@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1998-2000 Apple Computer, Inc. All rights reserved.
+ * Copyright (c) 1998-2003 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
@@ -37,13 +37,19 @@
 /*!
  * @defined kIOBlockStorageDeviceClass
  * @abstract
- * kIOBlockStorageDeviceClass is the name of the IOBlockStorageDevice class.
- * @discussion
- * kIOBlockStorageDeviceClass is the name of the IOBlockStorageDevice class.
+ * The name of the IOBlockStorageDevice class.
  */
 
 #define kIOBlockStorageDeviceClass "IOBlockStorageDevice"
 
+/*!
+ * @defined kIOBlockStorageDeviceWriteCacheStateKey
+ * @abstract
+ * The name of the property used to get or set the write cache state of the
+ * block storage device.
+ */
+#define kIOBlockStorageDeviceWriteCacheStateKey	"WriteCacheState"
+
 #ifdef KERNEL
 #ifdef __cplusplus
 
@@ -58,8 +64,10 @@
 
 /*!
  * @defined kIOMessageMediaStateHasChanged
- * The message ID which indicates that the media state has changed.  The message
- * is passed to all clients of the IOBlockStorageDevice via the message() method.
+ * @abstract
+ * The message ID which indicates that the media state has changed.
+ * @discussion
+ * The message is passed to all clients of the IOBlockStorageDevice via the message() method.
  * The argument that is passed along with this message is an IOMediaState value.
  *
  * Devices that aren't capable of detecting media state changes indicate this in
@@ -70,21 +78,21 @@
 /* Property used for matching, so the generic driver gets the nub it wants. */
 /*!
  * @defined kIOBlockStorageDeviceTypeKey
- * The name of the property tested for nub type matching by the generic block
+ * @abstract The name of the property tested for nub type matching by the generic block
  * storage driver.
  */
 #define	kIOBlockStorageDeviceTypeKey	"device-type"
 /*!
  * @defined kIOBlockStorageDeviceTypeGeneric
- * A character string used for nub matching.
+ * @abstract A character string used for nub matching.
  */
 #define	kIOBlockStorageDeviceTypeGeneric	"Generic"
 
 /*!
  * @class
- * IOBlockStorageDevice : public IOService
+ * IOBlockStorageDevice
  * @abstract
- * The IOBlockStorageDevice class is a generic block storage device abstraction.
+ * A generic block storage device abstraction.
  * @discussion
  * The IOBlockStorageDevice class exports the generic block storage protocol,
  * independent of the physical connection protocol (e.g. SCSI, ATA, USB),
@@ -117,6 +125,8 @@ public:
 
     /* Overrides from IORegistryEntry */
 
+    using IORegistryEntry::getProperty;
+
     /*!
      * @function init
      * @discussion
@@ -129,6 +139,10 @@ public:
      */    
     virtual bool	init(OSDictionary * properties);
 
+    virtual OSObject *	getProperty(const OSSymbol * key) const;
+
+    virtual IOReturn	setProperties(OSObject * properties);
+
     /* --- A subclass must implement the the following methods: --- */
 
     /*!
@@ -137,7 +151,7 @@ public:
      * Start an asynchronous read or write operation.
      * @param buffer
      * An IOMemoryDescriptor describing the data-transfer buffer. The data direction
-     * is contained in the IOMemoryDescriptor. Responsiblity for releasing the descriptor
+     * is contained in the IOMemoryDescriptor. Responsibility for releasing the descriptor
      * rests with the caller.
      * @param block
      * The starting block number of the data transfer.
@@ -148,7 +162,7 @@ public:
      */
 
     virtual IOReturn	doAsyncReadWrite(IOMemoryDescriptor *buffer,
-                                            UInt32 block,UInt32 nblks,
+                                            UInt32 block, UInt32 nblks,
                                             IOStorageCompletion completion)	= 0;
 
     /* DEPRECATED */ virtual IOReturn	doSyncReadWrite(IOMemoryDescriptor *buffer,
@@ -159,7 +173,7 @@ public:
      * @abstract
      * Eject the media.
      */
-    virtual IOReturn	doEjectMedia(void)					= 0;
+    virtual IOReturn	doEjectMedia(void)	= 0;
 
     /*!
      * @function doFormatMedia
@@ -171,7 +185,7 @@ public:
      * @param byteCapacity
      * The byte capacity to which the device is to be formatted, if possible.
      */
-    virtual IOReturn	doFormatMedia(UInt64 byteCapacity)			= 0;
+    virtual IOReturn	doFormatMedia(UInt64 byteCapacity)	= 0;
 
     /*!
      * @function doGetFormatCapacities
@@ -182,7 +196,8 @@ public:
      * @param capacities
      * Pointer for returning the list of capacities.
      * @param capacitiesMaxCount
-     * The number of capacity values returned in "capacities."
+     * The number of capacity values returned in "capacities," or if no buffer
+     * is given, the total number of capacity values available.
      */
     virtual UInt32	doGetFormatCapacities(UInt64 * capacities,
                                             UInt32   capacitiesMaxCount) const	= 0;
@@ -196,7 +211,7 @@ public:
      * @param doLock
      * True to lock the media, False to unlock.
      */
-    virtual IOReturn	doLockUnlockMedia(bool doLock)				= 0;
+    virtual IOReturn	doLockUnlockMedia(bool doLock)	= 0;
 
     /*!
      * @function doSynchronizeCache
@@ -205,7 +220,7 @@ public:
      * @discussion
      * This method should only be called if the media is writable.
      */
-    virtual IOReturn	doSynchronizeCache(void)				= 0;
+    virtual IOReturn	doSynchronizeCache(void)	= 0;
     
     /*!
      * @function getVendorString
@@ -214,7 +229,7 @@ public:
      * @result
      * A pointer to a static character string.
      */
-    virtual char *	getVendorString(void)					= 0;
+    virtual char *	getVendorString(void)	= 0;
     
     /*!
      * @function getProductString
@@ -223,7 +238,7 @@ public:
      * @result
      * A pointer to a static character string.
      */
-    virtual char *	getProductString(void)					= 0;
+    virtual char *	getProductString(void)	= 0;
     
     /*!
      * @function getRevisionString
@@ -232,7 +247,7 @@ public:
      * @result
      * A pointer to a static character string.
      */
-    virtual char *	getRevisionString(void)					= 0;
+    virtual char *	getRevisionString(void)	= 0;
     
     /*!
      * @function getAdditionalDeviceInfoString
@@ -241,7 +256,7 @@ public:
      * @result
      * A pointer to a static character string.
      */
-    virtual char *	getAdditionalDeviceInfoString(void)			= 0;
+    virtual char *	getAdditionalDeviceInfoString(void)	= 0;
 
     /*!
      * @function reportBlockSize
@@ -250,7 +265,7 @@ public:
      * @param blockSize
      * Pointer to returned block size value.
      */    
-    virtual IOReturn	reportBlockSize(UInt64 *blockSize)			= 0;
+    virtual IOReturn	reportBlockSize(UInt64 *blockSize)	= 0;
 
     /*!
      * @function reportEjectability
@@ -262,7 +277,7 @@ public:
      * Pointer to returned result. True indicates the media is ejectable, False indicates
      * the media cannot be ejected under software control.
      */
-    virtual IOReturn	reportEjectability(bool *isEjectable)			= 0;
+    virtual IOReturn	reportEjectability(bool *isEjectable)	= 0;
 
     /*!
      * @function reportLockability
@@ -274,7 +289,7 @@ public:
      * Pointer to returned result. True indicates the media can be locked in place; False
      * indicates the media cannot be locked by software.
      */
-    virtual IOReturn	reportLockability(bool *isLockable)			= 0;
+    virtual IOReturn	reportLockability(bool *isLockable)	= 0;
 
     /*!
      * @function reportMaxReadTransfer
@@ -289,7 +304,7 @@ public:
      * @param max
      * Pointer to returned result.
      */
-    virtual IOReturn	reportMaxReadTransfer (UInt64 blockSize,UInt64 *max)	= 0;
+    virtual IOReturn	reportMaxReadTransfer (UInt64 blockSize, UInt64 *max)	= 0;
 
     /*!
      * @function reportMaxWriteTransfer
@@ -313,7 +328,7 @@ public:
      * @param maxBlock
      * Pointer to returned result
      */    
-    virtual IOReturn	reportMaxValidBlock(UInt64 *maxBlock)			= 0;
+    virtual IOReturn	reportMaxValidBlock(UInt64 *maxBlock)	= 0;
 
     /*!
      * @function reportMediaState
@@ -353,7 +368,7 @@ public:
      * False indicates that the polling operation is cheap.
      */
     virtual IOReturn	reportPollRequirements(bool *pollRequired,
-                                            bool *pollIsExpensive)		= 0;
+                                            bool *pollIsExpensive)	= 0;
     
     /*!
      * @function reportRemovability
@@ -366,7 +381,7 @@ public:
      * Pointer to returned result. True indicates that the media is removable; False
      * indicates the media is not removable.
      */
-    virtual IOReturn	reportRemovability(bool *isRemovable)  			= 0;
+    virtual IOReturn	reportRemovability(bool *isRemovable)  	= 0;
     
     /*!
      * @function reportWriteProtection
@@ -377,7 +392,7 @@ public:
      * cannot be written); False indicates that the media is not write-protected (it
      * is permissible to write).
      */
-    virtual IOReturn	reportWriteProtection(bool *isWriteProtected)		= 0;
+    virtual IOReturn	reportWriteProtection(bool *isWriteProtected)	= 0;
 
     /*!
      * @function doAsyncReadWrite
@@ -385,7 +400,7 @@ public:
      * Start an asynchronous read or write operation.
      * @param buffer
      * An IOMemoryDescriptor describing the data-transfer buffer. The data direction
-     * is contained in the IOMemoryDescriptor. Responsiblity for releasing the descriptor
+     * is contained in the IOMemoryDescriptor. Responsibility for releasing the descriptor
      * rests with the caller.
      * @param block
      * The starting block number of the data transfer.
@@ -394,15 +409,41 @@ public:
      * @param completion
      * The completion routine to call once the data transfer is complete.
      */
-
     virtual IOReturn	doAsyncReadWrite(IOMemoryDescriptor *buffer,
-                                            UInt64 block,UInt64 nblks,
+                                            UInt64 block, UInt64 nblks,
                                             IOStorageCompletion completion);
 
     OSMetaClassDeclareReservedUsed(IOBlockStorageDevice, 0); /* 10.2.0 */
 
-    OSMetaClassDeclareReservedUnused(IOBlockStorageDevice,  1);
-    OSMetaClassDeclareReservedUnused(IOBlockStorageDevice,  2);
+    /*!
+     * @function getWriteCacheState
+     * @abstract
+     * Reports the current write cache state of the device.
+     * @discussion
+     * Reports the current write cache state of the device.  The write cache
+     * state is not guaranteed to persist across reboots and detaches.
+     * @param enabled
+     * Pointer to returned result. True indicates the write cache is enabled;
+     * False indicates the write cache is disabled.
+     */
+    virtual IOReturn	getWriteCacheState(bool *enabled);
+
+    OSMetaClassDeclareReservedUsed(IOBlockStorageDevice, 1); /* 10.3.0 */
+
+    /*!
+     * @function setWriteCacheState
+     * @abstract
+     * Sets the write cache state of the device.
+     * @discussion
+     * Sets the write cache state of the device.  The write cache state
+     * is not guaranteed to persist across reboots and detaches.
+     * @param enabled
+     * True to enable the write cache; False to disable the write cache.
+     */
+    virtual IOReturn	setWriteCacheState(bool enabled);
+
+    OSMetaClassDeclareReservedUsed(IOBlockStorageDevice, 2); /* 10.3.0 */
+
     OSMetaClassDeclareReservedUnused(IOBlockStorageDevice,  3);
     OSMetaClassDeclareReservedUnused(IOBlockStorageDevice,  4);
     OSMetaClassDeclareReservedUnused(IOBlockStorageDevice,  5);
